Copy the current schema to this directory at:
schema-latest.graphql

    For now we don't want this checked in

https://github.com/wandb/core/releases/tag/local%2Fv0.57.4
https://github.com/wandb/core/blob/abb9f152fdbfccace9bc6550fd0b8dba424ba3e1/services/gorilla/schema.graphql
